AuthEvents class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

onForbidden Stream<ForbiddenEvent>
no setter
onUnauthorized Stream<UnauthorizedEvent>
no setter

Static Methods

dispose() Future<void>
emitForbidden(ForbiddenEvent e) → void
emitUnauthorized(UnauthorizedEvent e) → void