ApiEnvelope class

Constructors

ApiEnvelope({required bool success, required String message, Map<String, dynamic>? raw})
const
ApiEnvelope.fromResponse(dynamic responseBody)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
raw Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

copyWith({bool? success, String? message, Map<String, dynamic>? raw}) ApiEnvelope
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited