ApiRequest<T> class
sealed
- Implementers
Properties
- endpoint → String
-
final
- fromJson → T Function(dynamic json)?
-
final
- fullPath → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
no setter
- noAuth → bool
-
no setter
- options → ApiRequestOptions?
-
final
-
query
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited