GetRequest<T> class
- Inheritance
-
- Object
- ApiRequest<
T> - GetRequest
Constructors
-
GetRequest({required String endpoint, T fromJson(dynamic json)?, String version = '', Map<
String, dynamic> ? query, ApiGetRequestOptions? options}) -
const
Properties
- cache → bool
-
no setter
- cacheKey → String
-
no setter
- cacheTtl → Duration?
-
no setter
- endpoint → String
-
finalinherited
- forceRefresh → bool
-
no setter
- fromJson → T Function(dynamic json)?
-
finalinherited
- fullPath → String
-
no setterinherited
- getOptions → ApiGetRequestOptions?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
no setterinherited
- invalidateCache → bool
-
no setter
- noAuth → bool
-
no setterinherited
- options → ApiRequestOptions?
-
finalinherited
-
query
→ Map<
String, dynamic> ? -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited