PutRequest<T> class
- Inheritance
-
- Object
- ApiRequest<
T> - PutRequest
Constructors
-
PutRequest({required String endpoint, T fromJson(dynamic json)?, String version = '', Map<
String, dynamic> ? query, ApiRequestOptions? options, Map<String, dynamic> ? body}) -
const
Properties
-
body
→ Map<
String, dynamic> ? -
final
- endpoint → String
-
finalinherited
- fromJson → T Function(dynamic json)?
-
finalinherited
- fullPath → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
no setterinherited
- noAuth → bool
-
no setterinherited
- options → ApiRequestOptions?
-
finalinherited
-
query
→ Map<
String, dynamic> ? -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited