UploadFile class

Describes a single file to be uploaded.

Constructors

UploadFile.fromBytes({required String field, required List<int>? bytes, required String? filename})
const
UploadFile.fromPath({required String field, required String? path, String? filename})
const
UploadFile.fromStream({required String field, required Stream<List<int>>? stream, required String? filename, required int length})
const

Properties

bytes List<int>?
final
field String
final
filename String?
final
hashCode int
The hash code for this object.
no setterinherited
length int
no setter
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<List<int>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMultipart() Future<MapEntry<String, MultipartFile>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited