ApiGetRequestOptions class

Inheritance

Constructors

ApiGetRequestOptions({Map<String, String>? headers, bool noAuth = false, bool cache = true, Duration? cacheTtl, bool forceRefresh = false, bool invalidateCache = false})
const

Properties

cache bool
final
cacheTtl Duration?
final
forceRefresh bool
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
finalinherited
invalidateCache bool
final
noAuth bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited