apply abstract method
Attach auth credentials to options before the request is sent.
Implementation
Future<void> apply(RequestOptions options);
Attach auth credentials to options before the request is sent.
Future<void> apply(RequestOptions options);