onUnauthorized method
Called when the API layer receives a 401. Use to trigger token refresh or logout in your app provider.
Implementation
Future<void> onUnauthorized() async {}
Called when the API layer receives a 401. Use to trigger token refresh or logout in your app provider.
Future<void> onUnauthorized() async {}