tokenKey property
Hive box key used to persist the token.
Must match the key used when saving after login.
e.g. 'access_token'
Implementation
final String tokenKey;
Hive box key used to persist the token.
Must match the key used when saving after login.
e.g. 'access_token'
final String tokenKey;