UploadNotifier class

Inheritance

Constructors

UploadNotifier()

Properties

debugState → AsyncValue<ApiResult>
A development-only way to access state outside of StateNotifier.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
If a listener has been added using addListener and hasn't been removed yet.
no setterinherited
mounted bool
Whether dispose was called or not.
no setterinherited
onError ↔ ErrorListener?
A callback for error reporting if one of the listeners added with addListener throws.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ↔ AsyncValue<ApiResult>
The current "state" of this StateNotifier.
getter/setter pairinherited
stream Stream<AsyncValue<ApiResult>>
A broadcast stream representation of a StateNotifier.
no setterinherited

Methods

addListener(Listener<AsyncValue<ApiResult>> listener, {bool fireImmediately = true}) → RemoveListener
Subscribes to this object.
inherited
cancel() → void
Cancel the in-progress upload.
dispose() → void
Frees all the resources associated with this object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateShouldNotify(AsyncValue<ApiResult> old, AsyncValue<ApiResult> current) bool
Whether to notify listeners or not when state changes
inherited
upload<T>(UploadRequest<T> request) Future<ApiResult<T>>
Execute an upload request. Progress is emitted on uploadProgressStreamProvider. Returns the ApiResult and also updates state.

Operators

operator ==(Object other) bool
The equality operator.
inherited