UploadRequest<T> class

Inheritance

Constructors

UploadRequest({required String endpoint, T fromJson(dynamic json)?, required List<UploadFile> files, String version = '', ApiRequestOptions? options, Map<String, String>? fields, UploadMethod method = UploadMethod.post})
const

Properties

endpoint String
finalinherited
fields Map<String, String>?
final
files List<UploadFile>
final
fromJson → T Function(dynamic json)?
finalinherited
fullPath String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
no setterinherited
method UploadMethod
final
noAuth bool
no setterinherited
options ApiRequestOptions?
finalinherited
query Map<String, dynamic>?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited