UploadProgress class
Snapshot of an in-progress upload.
Constructors
- UploadProgress({required int sent, required int total})
-
const
- UploadProgress.done(int bytes)
-
const
- UploadProgress.idle()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDone → bool
-
True when the upload has completed (sent == total and total > 0).
no setter
- percent → double
-
0.0 → 1.0 progress ratio. Returns 0 if total is unknown.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sent → int
-
final
- sentMB → double
-
Megabytes sent.
no setter
- total → int
-
final
- totalMB → double
-
Total megabytes.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited